Monty Python's Flying Circus: Just the Words - Episode 32

# Episode Thirty-two

Tory Housewives Clean-up Campaign
Gumby brain specialist
Molluscs - 'live' TV documentary
The Minister for not listening to people
Tuesday documentary/children's story/party political broadcast
Apology (politicians)
Expedition to Lake Pahoe
The silliest interview we've ever had
The silliest sketch we've ever done

Colour code: John Cleese - Michael Palin - Eric Idle - Graham Chapman - Terry Jones - Terry Gilliam - Carol Cleveland

| Newsreel footage.
Voice Over | (newsreel voice) In the modern Britain, united under a great leader, it's the housewives of Britain who are getting things moving. (Red Devils flying; picture of Edward Heath) Here a coachload of lovely ladies are on their way to speed up production in a car factory. (coach load of pepperpots, middle class, grey hair, Mary Whitehouse glasses; the coach says 'Tory Tours') And here we are boys, it's the no-hurry brigade hanging about for endless overtime. And just watch these gallant girls go into action . .. (cut to a factory yard; some workers in brown overalls are eating sandwiches out of tins; the clock says 1:15; the coach comes swinging in in undercrank, the ladies pour out about to belt the men with umbrellas and handbags; the men flee back into factories) Not working fast enough? Well, there's an answer for that. (a man at a machine, producing something incredibly fast; a pepperpot holds an enormous sledgehammer) Yes, this is certainly the way to speed up production. (wide shot of factory interior; three pepperpots stand on a gantry above work floor, wearing armbands, saying 'P.P.' and dark Mary Whitehouse glasses) This is the recipe for increased productivity to meet the threat of those nasty foreigners when Britain takes her natural place at the head of the British Common Market. (a group of strikers, picketing with slogans, 'Fair Pay', 'Less Profits', 'Parity', 'No Victimization') And how's this for a way to beat strikers. (pepperpots arrive, clinging to side of old Buick; they race in and start beating the strikers with the banners) Those spotty continental boys will soon have to look out for Mrs Britain, and talking of windmills, these girls aren't afraid to tilt at the permissive society, (art gallery exterior; pepperpots run in with bundles and ladders) Business is booming in the so-called arts, but two can play at that game, chum. (cut to art gallery interior, pan around paintings 'cleaned up'- trousers and cardigans being added to nude pictures and statues, Bermuda shorts on David, shorts on tubular structure, an attendant in shorts too). And it's not just the modern so-called plastic arts that get the clean-up treatment.
| Cut to a theatre stage. Desdemona on a bed. Othello with her.
Othello | Oh Desdemona, Desdemona.
| The pepperpots race on to the stage and pull him off.
Voice Over | And those continentals had better watch out for their dirty foreign literature. Jean-Paul Sartre and Jean Genet won't know what's hit them. Never mind the foulness of their language - come '73 they'll all have to write in British. (pepperpots burning books: 'Bertrand Russell', 'Das Kapital', the 'Guardian', 'Sartre', 'Freud') You can keep your fastidious continental bidets Mrs Foreigner - Mrs Britain knows how to keep her feet clean ... but she'll baffle like bingo boys when it comes to keeping the television screen clean...
| Cut to the BBC TV Centre. The peppetpots parade in carrying signs: 'Clean TV Centre', 'God Says No To Filth', 'To The Cells'. Another pepperpot in the background holds a sign: 'Wanted Dead Or Alive' and photo of Robert Robinson.
Voice Over | Better watch out for those nasty continental shows on the sneaky second channel. (armed pepperpots escorting people out of TV Centre) But apart from attacking that prurient hot-bed of left-wing continentalism at Shepherds Bush, what else do these ordinary mums think? Do they accept Hegelianism?
First Pepperpot | No! ..
Voice Over | Do they prefer Leibnitz to Wittgenstein?
Second Pepperpot | No! No!
Voice Over | And where do they stand on young people?
Third Pepperpot | Just here, dear. (pepperpot standing on long-haired youth's head)
Voice Over | And their power is growing daily and when these girls roll their sleeves up its arms all the way. (pepperpots standing on the turret of an armoured vehicle; four pepperpots on motor bikes flank it) Yes, this is the way to fight the constant war against pornography.
| Machine guns chatter. Two pepperpots in a trench firing. Mortar bombs, reloading and firing. Bombs and smoke. At the end of the film we pick up on the nude organist (Terry J), sitting amongst the explosions. He plays his chords.
Announcer | And now...
It's Man | It's...
| Animated titles.
Voice | Monty Python's Flying Circus.
| Close up on a sign saying 'Harley Street'. Stirring music. Mix through to interior of a smart, plush, ever so expensive Harley Street consulting room. The music swells and fades. Knocking at door, a short pause, then T.F. Gumby enters, backwards.
T. F. Gumby | Doctor! Doctor! DOCTOR! (he goes up to the antique desk and bangs the bell violently; he smashes the intercom and generally breaks the desk up) Doctor! Doctor! DOCTOR! DOCTOR! Doctor! Doctor! Where is the Doctor?
| A pause. Then another door opens and another Gumby appears.
Specialist | Hello!
T. F. Gumby | Are you the brain specialist?
Specialist | Hello!
T. F. Gumby | Are you the brain specialist?
Specialist | No, no, I am not the brain specialist. No, no, I am not... Yes. Yes I am.
T. F. Gumby | My brain hurts!
Specialist | Well let's take a look at it, Mr Gumby.
| Gumby specialist starts to pull up Gumby's sweater.
T. F. Gumby | No, no, no, my brain in my head. (specialist thumps him on the head)
Specialist | It will have to come out.
T. F. Gumby | Out? Of my head?
Specialist | Yes! All the bits of it. Nurse! Nurse! (a nurse enters) NURSE! NURSE! Nurse, take Mr Gumby to a brain surgeon.
Nurse | Yes doctor...
| She leads Gumby out. In the background the specialist is grunting and shouting.
Specialist | Where's the 'Lancet'?
Nurse | (to T. F. Gumby) He's brilliant you know.
Specialist | Where's the bloody 'Lancet'? My brain hurts too.
| Ambulance racing. 'Dr Kildare' theme. Cut to operating theatre. The surgeon is not a Gumby.
Surgeon | (putting on Gumby props) Gloves ... glasses... moustache... handkerchief... (Gumby voice) I'm going to operate!!
| We now see he is surrounded by Gumbys. T. F. Gumby is on operating table.
All | Let's operate.
| They begin to use woodworking implements on T. F. Gumby.
T. F. Gumby | Hello!
Surgeon | Ooh! We forgot the anaesthetic!
Operating Gumbys | The anaesthetic! The anaesthetic!
| At that moment a Gumby anaesthetist comes crashing through the wall with two gas cylinders.
Gumby Anaesthetist | I've come to anaesthetize you!!
| He raises a gas cylinder and strikes Gumby hard over the head with it. Bong. Blackness. Into the oblivion of animation. Then cut to an ordinary suburban living room. Mr and Mrs Jalin are sitting on a sofa. The previous item in the show is visible on their TV set. Mrs Jalin is stuffing a chicken. Mr Jalin is reading the telephone directory. The picture changes and we hear voice from TV.
Voice | The 'Nine O'Clock News' which was to follow has been cancelled tonight so we can bring you the quarter finals of the All Essex Badminton Championship. Your commentator as usual is Edna O'Brien.
Commentator | (Irish accent) Hullo fans. Begorra an' to be sure there's some fine badminton down there in Essex this afternoon. We really...
| Mr Jalin picks up a jousting ball and chain and smashes the TV set. There is a ring from the doorbell. Mr Jalin sits, Mrs Jalin goes to the door, exits and comes back.
Mrs Jalin | George.
Mr Jalin | Yes, Gladys.
Mrs Jalin | There's a man at the door with a moustache.
Mr Jalin | Tell him I've already got one. (Mrs Jalin hits him hard with a newspaper) All right, all right. What's he want then?
Mrs Jalin | He says do we want a documentary on molluscs.
Mr Jalin | Molluscs?!
Mrs Jalin | Yes.
Mr Jalin | What's he mean, molluscs?
Mrs Jalin | MOLLUSCS!! GASTROPODS! LAMELLIBRANCHS! CEPHALOPODS!
Mr Jalin | Oh molluscs, I thought you said bacon. (she hits him again) All right, all right. What's he charge then?
Mrs Jalin | It's free.
Mr Jalin | Ooh! Where does he want us to sit?
Mrs Jalin | (calling through the door) He says yes.
| Mr Zorba enters carrying plywood flat with portion cut out to represent TV. He stands behind flat and starts.
Zorba | Good evening. Tonight molluscs. The mollusc is a soft-bodied, unsegmented invertebrate animal usually protected by a large shell. One of the most numerous groups of invertebrates, it is exceeded in number of species only by the arthropods ... viz. (he holds up a lobster)
Mrs Jalin | Not very interesting is it?
Zorba | What?
Mrs Jalin | I was talking to him.
Zorba | Oh. Anyway, the typical mollusc, viz, a snail (holds one up) consists of a prominent muscular portion... the head-foot... a visceral mass and a shell which is secreted by the free edge of the mantle.
Mrs Jalin | Dreadful isn't it?
Zorba | What?
Mrs Jalin | I was talking to him.
Zorba | Oh. Well anyway... in some molluscs, however, viz, slugs, (holds one up) the shell is absent or rudimentary...
Mr Jalin | Switch him off.
| Mrs Jalin gets up and looks for the switch unsuccessfully.
Zorba | Whereas in others, viz, cephalopods the head-foot is greatly modified and forms tentacles, viz, the squid. (looking out) What are you doing?
Mrs Jalin | Switching you off.
Zorba | Why, don't you like it?
Mrs Jalin | Oh it's dreadful.
Mr Jalin | Embarrassing.
Zorba | Is it?
Mrs Jalin | Yes, it's perfectly awful.
Mr Jalin | Disgraceful! I don't know how they've got the nerve to put it on.
Mrs Jalin | It's so boring.
Zorba | Well ... it's not much of a subject is it... be fair.
Mrs Jalin | What do you think, George?
Mr Jalin | Give him another twenty seconds.
Zorba | Anyway the majority of the molluscs are included in three large groups, the gastropods, the lamellibranchs and the cephalopods...
Mrs Jalin | We knew that (she gets up and goes to the set)
Zorba | However, what is more interesting, er ... is the molluscs's er ... sex life.
Mrs Jalin | (stopping dead) Oh!
Zorba | Yes, the mollusc is a randy little fellow whose primitive brain scarcely strays from the subject of the you know what.
Mrs Jalin | (going back to sofa) Disgusting!
Mr Jalin | Ought not to be allowed.
Zorba | The randiest of the gastropods is the limpet. This hot-blooded little beast with its tent-like shell is always on the job. Its extra-marital activities are something startling. Frankly I don't know how the female limpet finds the time to adhere to the rock-face. How am I doing?
Mrs Jalin | Disgusting.
Mr Jalin | But more interesting.
Mrs Jalin | Oh yes, tch, tch, tch.
Zorba | Another loose-living gastropod is the periwinkle. This shameless little libertine with its characteristic ventral locomotion ... is not the marrying kind: 'Anywhere anytime' is its motto. Up with the shell and they're at it.
Mrs Jalin | How about the lamellibranchs?
Zorba | I'm coming to them ... the great scallop (holds one up) ... this tatty, scrofulous old rapist, is second in depravity only to the common clam. (holds up a clam) This latter is a right whore, a harlot, a trollop, a cynical bed-hopping firm-breasted Rabelaisian bit of sea food that makes Fanny Hill look like a dead Pope... and finally among the lamellibranch bivalves, that most depraved of the whole sub-species - the whelk. The whelk is nothing but a homosexual of the worst kind. This gay boy of the gastropods, this queer crustacean, this mincing mollusc, this screaming, prancing, limp-wristed queen of the deep makes me sick.
Mrs Jalin | Have you got one?
Zorba | Here! (holds one up)
Mrs Jalin | Let's kill it. Disgusting.
| Zorba throws it on the floor and Mr and Mrs Jalin stamp on it.
Mr Jalin | That'll teach it. Well thank you for a very interesting programme.
Zorba | Oh, not at all. Thank you.
Mrs Jalin | Yes, that was very nice.
Zorba | Thank you. (he shakes hands with her)
Mrs Jalin | Oh, thank you.
| Cut to a studio presenter at a desk.
Presenter | And now a word from the man in the...
| Cut to Glencoe vox pop: a loony.
Loony | ...street.
| ANIMATION: high-suction baby.
| Cut to a 'Nine O'clock News' set. A newsreader is at a desk. Photos come up on inlay screen behind him. An anonymous minister's photo is on screen.
Newsreader | The Minister for not listening to people toured Batley today to investigate allegations of victimization in home-loan improvement grants, made last week (photo behind changes to close up of another faceless minister) by the Shadow Minister for judging people at first sight to be marginally worse than they actually are. (photo changes to exterior of the Home Office) At the Home Office, the Minister for inserting himself in between chairs and walls in men's clubs, was at his desk after a short illness. He spent the morning dealing with the Irish situation and later in the day had long discussions with the Minister for running upstairs two at a time, flinging the door open and saying 'Ha, ha! Caught you, Mildred'. (photo of the Houses of Parliament) In the Commons there was another day of heated debate on the third reading of the Trade Practices Bill. Mr Roland Penrose, the Under-Secretary for making deep growling noises grrr, launched a bitter personal attack on the ex-Minister for delving deep into a black satin bag and producing a tube of Euthymol toothpaste. Later in the debate the Junior Minister for being frightened by any kind of farm machinery, challenged the Under-Secretary of State for hiding from Terence Rattigan to produce the current year's trading figures, as supplied by the Department of stealing packets of bandages from the self-service counter at Timothy Whites and selling them again at a considerable profit. Parliament rose at 11:30, and, crawling along a dark passageway into the old rectory (the camera starts to track slowly into the newsreader's face so that it is eventually filling the screen) broke down the door to the serving hatch, painted the spare room and next weekend I think they'll be able to make a start on the boy's bedroom, while Amy and Roger, up in London for a few days, go to see the mysterious Mr Grenville.
| SUPERIMPOSED CAPTION: 'TODAY IN PARLIAMENT HAS NOW BECOME THE CLASSIC SERIAL'
Newsreader | He in turn has been revealed by D'Arcy as something less than an honest man. Sybil feels once again a resurgence of her old affection and she and Balreau return to her little house in Clermont-Ferrand, the kind of two-up, two-down house that most French workers throughout the European Community are living in today.
| SUPERIMPOSED CAPTION: 'THE CLASSIC SERIAL HAS NOW BECOME THE TUESDAY DOCUMENTARY'
| Cut to a photo of a French construction site. The camera tracks over the photo.
Presenter | The ease of construction, using on-site prefabrication facilities (the camera starts to pull out slowly from the photo to reveal the photo is part of the backdrop of a documentary set about the building trade; the documentary presenter is sitting in a chair) makes cheap housing a reality. The walls of these houses are lined with prestressed asbestos which keeps the house warm and snuggly and ever so safe from the big bad rabbit, who can scratch and scratch for all he's worth, but he just can't get into Porky's house.
| SUPERIMPOSED CAPTION: 'THE TUESDAY DOCUMENTARY HAS BECOME "CHILDREN'S STORY" '
Presenter | Where is Porky? Here he is. What a funny little chap. (cut to animated Porky doing little dance) But Porky's one of the lucky ones - he survived the urban upheaval of the thirties and forties. For him, Jarrow is still just a memory. (zoom out to see Porky as part of documentary-type graph) The hunger marches, the East End riots, the collapse of the Labour Government in 1931... (stock film of Ramsay MacDonald)
| SUPERIMPOSED CAPTION: 'THE CHILDREN'S STORY HAS GONE BACK INTO THE TUESDAY DOCUMENTARY'
Presenter | ... are dim reminders of the days before a new-found affluence swept the land, (stock shots of Christmas lights in Regent Street, shopping crowds, tills and consumer goods ending up with toys) making it clean and tidy and making all the shops full of nice things, lovely choo-choo trains ...
| SUPERIMPOSED CAPTION: 'NO IT HASN'T'
Presenter | . .. and toys and shiny cars that go brrm, brrm, brrm, (shots of toys) and everybody was happy and singing all the day long (cut to the Presenter; by now he has a big kiddies' book which he shuts) and nobody saw the big bad rabbit ever again.
| Cut to a politican giving a party political broadcast in one of those badly lit sets that they use for broadcasts of that nature.
Politician | But you know it's always very easy to blame the big bad rabbit...
| SUPERIMPOSED CAPTION: 'NOW IT'S BECOME A PARTY POLITICAL BROADCAST!'
Politician | ...when by-elections are going against the Government, (he turns and we cut to side camera which reveals a cross behind him as for religious broadcast) Do you think we should really be blaming ourselves?
| SUPERIMPOSED CAPTION: 'NO, SORRY, "'RELIGION TODAY" '
Politician | Because you know, that's where we really ought to start looking.
| A football comes in, he heads it neatly out of shot.
| SUPERIMPOSED CAPTION: 'MATCH OF THE DAY'
| Cut to stock film of ball flying into net and shot of Wembley crowd roaring. Then cut into short sequence of footballers in slow-motion kissing each other.
| SUPERIMPOSED CAPTION: 'POLITICIANS - AN APOLOGY'
| The camera pans across a landscape. Roller caption starts to come up, superimposed. The words are quite large and easily readable, but well spaced so that the roller will seem to go on for quite some time. Voice over reads.
Voice Over | (and CAPTION:) 'WE WOULD LIKE TO APOLOGIZE FOR THE WAY IN WHICH POLITICIANS ARE REPRESENTED IN THIS PROGRAMME. IT WAS NEVER OUR INTENTION TO IMPLY THAT POLITICIANS ARE WEAK-KNEED, POLITICAL TIME-SERVERS WHO ARE CONCERNED MORE WITH THEIR PERSONAL VENDETTAS AND PRIVATE POWER STRUGGLES THAN THE PROBLEMS OF GOVERNMENT, NOR TO SUGGEST AT ANY POINT THAT THEY SACRIFICE THEIR CREDIBILITY BY DENYING FREE DEBATE ON VITAL MATTERS IN THE MISTAKEN IMPRESSION THAT PARTY UNITY COMES BEFORE THE WELL-BEING OF THE PEOPLE THEY SUPPOSEDLY REPRESENT NOR TO IMPLY AT ANY STAGE THAT THEY ARE SQUABBLING LITTLE TOADIES WITHOUT AN OUNCE OF CONCERN FOR THE VITAL SOCIAL PROBLEMS OF TODAY. NOR INDEED DO WE INTEND THAT VIEWERS SHOULD CONSIDER THEM AS CRABBY ULCEROUS LITTLE SELF-SEEKING VERMIN WITH FURRY LEGS AND AN EXCESSIVE ADDICTION TO ALCOHOL AND CERTAIN EXPLICIT SEXUAL PRACTICES WHICH SOME PEOPLE MIGHT FIND OFFENSIVE. WE ARE SORRY IF THIS IMPRESSION HAS COME ACROSS.
| Cut to a similar landscape. Preparations for an expedition are underway: equipment being piled into land-rovers etc. An interviewer walks into shot.
Interviewer | Hello. All the activity you can see in progress here is part of the intricate... aah! (he steps into a man-trap, but continues bravely) preparations for the British Naval Expedition to Lake Pahoe. The leader of the expedition is Sir Jane Russell. (the interviewer in slightly different spot with the admiral; we now see that the interviewer has a wooden leg and a crutch) Sir Jane, what is the purpose of your expedition?
Sir Jane | Well this is a completely uncharted lake with like hitherto unclassified marine life man, so the whole scene's wide open for a scientific exploration.
Interviewer | (now with a parrot on his shoulder) One can see the immense amount of preparation involved. Have there been many difficulties in setting up this venture?
Sir Jane | (with 'naval-lib' badge) Well the real hang-up was with the bread man but when the top brass pigs came through we got it together in a couple of moons. Commodore Betty Grable, who's a real sub-aqua head, has got it together diving wise and like the whole gig's been a real gas man.
Interviewer | (now with Long John Silver hat) Thank you. (and eyepatch) Lieutenant Commander Dorothy Lamour.
Parrot | Pieces of eight.
Interviewer | (now with Long John Silver jacket) Dorothy you're in charge of security and liason for this operation.
Dorothy Lamour | Right on. (he is smoking something and is really cool)
Interviewer | You've kept this all rather hush-hush so far shipmate.
Dorothy Lamour | Yeah, it's been really heavy man with all these freaks from the fascist press trying to blow the whole scene.
Interviewer | (to camera) There's no doubt about it, this expedition does have some rather unusual aspects, Jim lad. For a first, why does the senior personnel all bear the names of Hollywood film stars of the forties ... and female ones at that, shiver me timbers 'tis the black spot, and secondly, I be not afraid of thee Blind Pew ... why do they talk this rather strange stilted, underground jargon, belay the mainbrace Squire Trelawney this be my ship now. (he is hit by a dart) Argh! A tranquillizing dart fired by the cowardly BBC health department dogs ... they've done filled me full of chlorpromazine damn!
| He falls. A second interviewer comes into shot and catches the microphone.
Second Interviewer | I'm sorry about my colleague's rather unconventional behaviour.
Sir Jane | (running towards the camera) The navy's out of sight man come together with the RN it's really something other than else.
| Animated psychedelic advert for the Royal Navy.
Animated Voice | You dig it, man?
| Cut back to second interviewer.
Second Interviewer | Hello. I'm sorry about my colleague's rather unconventional behaviour just now, but things haven't been too easy for him recently, trouble at home, rather confidential so I can't give you all the details... interesting though they are... three bottles of rum with his Weetabix, and so on, anyway... apparently the girl wasn't even ... anyway the activity you see behind me... it's the mother I feel sorry for. I'll start again. The activity you see behind me is part of the preparations for the new Naval Expedition to Lake Pahoe. The man in charge of this expedition is Vice Admiral Sir John Cunningham. Sir John, hello there.
Sir John | Ah, hello. Well first of all I'd like to apologize for the behaviour of certain of my colleagues you may have seen earlier, but they are from broken homes, circus families and so on and they are in no way representative of the new modern improved British Navy. They are a small vociferous minority; and may I take this opportunity of emphasizing that there is no cannibalism in the British Navy. Absolutely none, and when I say none, I mean there is a certain amount, more than we are prepared to admit, but all new ratings are warned that if they wake up in the morning and find any toothmarks at all anywhere on their bodies, they're to tell me immediately so that I can immediately take every measure to hush the whole thing up. And, finally, necrophilia is right out. (the interviewer keeps nodding but looks embarrassed) Now, this expedition is primarily to investigate reports of cannibalism and necrophilia in... this expedition is primarily to investigate reports of unusual marine life in the as yet uncharted Lake Pahoe.
Second Interviewer | And where exactly is the lake?
Sir John | Er 22A, Runcorn Avenue, I think. Yes, that's right, 22A.
Second Interviewer | Runcorn Avenue?
Sir John | Yes, it's just by Blenheim Crescent... do you know it?
Second Interviewer | You mean it's in an ordinary street?
Sir John | Of course it's not an ordinary street! It's got a lake in it!
Second Interviewer | Yes but I...
Sir John | Look, how many streets do you know that have got lakes in them?
Second Interviewer | But you mean... is it very large?
Sir John | Of course it's not large, you couldn't get a large lake in Runcorn Avenue! You'd have to knock down the tobacconist's! (looking off camera) Jenkins ... no!
| We see a rather sheepish rating about to sink his teeth into a human leg. Sir John puts his hand in front of the lens. Cut to Runcorn Avenue, an ordinary street with houses now turned into flats. The land-rover arrives with the equipment.
Second Interviewer | I'm now standing in Runcorn Avenue. Sir John ... where exactly is the lake?
Sir John | Er, well let's see, that's 18... that's 20 so this must be the one.
Second Interviewer | Er, excuse me...
Sir John | Yes, that's the one all right.
Second Interviewer | But it's an ordinary house.
Sir John | Look, I'm getting pretty irritated with this line of questioning.
Second Interviewer | But it doesn't even look like a lake...
Sir John | Look, your whole approach since this interview started has been to mock the Navy. When I think that it was for the likes of you that I had both my legs blown off...
Second Interviewer | (pointing at perfectly healthy legs) You haven't had both your legs blown off!
Sir John | I was talking metaphorically you fool. Jenkins - put that down. (Jenkins returns the leg to the land-rover) Right, is the equipment ready?
Rating | Diving equipment all ready man. (gives hippy salute)
Sir John | (warning finger) Right. Now quite simply the approach to Lake Pahoe is up the steps, and then we come to the shores of the lake. Now, I'm going to press the bell just to see if there's anyone in.
Man | (answering) Hello?
Sir John | Good morning - I'm looking for a Lake Pahoe.
Man | There's a Mr Padgett.
Sir John | No, no a lake.
Man | There's no lake here, mate. This is Runcorn Avenue. What's the camera doing?
Woman | (coming out) Camera? What's he want? Oooh, are we on the telly? (grins at the camera)
Man | He's looking for a lake.
Sir John | Lake Pahoe.
Woman | Oh, you want downstairs, 22A the basement.
Sir John | Ah! Thank you very much. Good morning. Come on men, downstairs.
| They walk down to the basement. The interviewer intercepts Sir John.
Second Interviewer | Were you successful, Sir John?
Sir John | It's in the basement.
Second Interviewer | In the basement?
| He sees a parrot on his shoulder.
Parrot | Pieces of eight.
Second Interviewer | Eugh! (he knocks it off)
| Sir John goes to the front door of 22A and rings. Then he looks into the living room through the window. A middle-aged couple are sitting inside. The room is full of water. The man reads the paper and the woman knits. Both wear breathing apparatus. Sir John knocks on the window. The woman looks up.
Sir John | Hello.
Woman | Ooooh. I think it's someone about the damp.
Sir John | Hello.
Man | Tell 'em about the bleeding rats, too.
Woman | I'll go (she swims to window and shouts out) Yes?
Sir John | Good morning, is this Lake Pahoe?
Woman | Well, I don't know about that, but it's bleeding damp. Are you from the council?
Sir John | No. We are the official British Naval Expedition to this lake. May we come in?
Woman | Hang on.
| She submerges and picks up a big sign showing it to the man. The sign reads 'It's not the council, it's a British Naval Expedition to Lake Pahoe or something and can they come in'. The man reads the card. An enormous shark looks over his shoulder appearing from a cupboard. The man sees it and hits it with a newspaper.
Man | Bloody sharks.
Woman | Get in.
| He holds up a sign reading 'Tell them to go away'. The woman swims to the window and gives a V-sign to Sir John.
Sir John | Well um... that would appear to be the end of the expedition.
| Cut to an interview set.
Interviewer | The Magna Carta - was it a document signed at Runnymede in 1215 by King John pledging independence to the English barons, or was it a piece of chewing gum on a bedspread in Dorset? The latter idea is the brainchild of a man new to the field of historical research. Mr Badger, why - why are you on this programme?
| Pull back to show Mr Badger. He wears a flat cap and has a Scots accent.
Badger | Well, I think I can answer this question most successfully in mime. (mimes incomprehensibly)
Interviewer | But why Dorset?
Badger | Well, I have for a long time been suffering from a species of brain injury which I incurred during the rigours of childbirth, and I'd like to conclude by putting my finger up my nose.
Interviewer | Mr Badger, I think you're the silliest person we've ever had on this programme, and so I'm going to ask you to have dinner with me.
| CAPTION: 'LATER THE SAME SKETCH'
| Cut to them sitting at a restaurant table.
Badger | My wife Maureen ran off with a bottle of Bell's whisky during the Aberdeen versus Raith Rovers match which ended in a goalless draw. Robson particularly, in goal, had a magnificent first half, his fine positional sense preventing the build-up of any severe pressure on the suspect Aberdeen defense. McLoughlan missed an easy chance to clinch the game towards the final whistle but Raith must be well satisfied with their point.
Interviewer | Do please go on. This is the least fascinating conversation I've ever had.
| A waiter comes in.
Waiter | Would you like to order sir?
Interviewer | Yes, Mr Badger, what would you like to start with?
Badger | Er, I'll have a whisky to start with.
Waiter | For first course, sir?
Badger | Aye.
Waiter | And for main course, sir?
Badger | I'll have a whisky for main course and I'll follow that with a whisky for pudding.
Waiter | Yes sir, and what would you like with it, sir? A whisky?
Badger | No, a bottle of wine.
Waiter | Fine, sir, he said between clenched teeth knowing full well it was a most unrewarding part.
Interviewer | This is the silliest sketch I've ever been in.
Badger | Shall we stop it?
Interviewer | Yeah, all right. (they get up and walk out)
| CAPTION: 'THE END'
| CREDITS